@@ -1,6 +1,6 @@
 from collections.abc import Iterable, Callable
 from .attribute import _tpl_attribute_function, _tpl_attribute_variable
-
+from .curve_label import _tpl_curve_label
 
 class _tpl_curve_data:
   __counter: int = 0
@@ -20,7 +20,8 @@ class _tpl_curve_data:
     return x, y, xerr, yerr
 
   def __init__(self, x: Iterable, y: Iterable, xerror: Iterable = None, yerror: Iterable = None,
-               label: str = None, color: str = None, yfunc: Callable = None, sortdata: bool = True):
+               label: str = None, color: str = None, opacity: str = None, yfunc: Callable = None,
+               sortdata: bool = True, mark: str = None):
     if yfunc is not None:
       y = map(yfunc, y)
       if yerror is not None:
@@ -29,14 +30,16 @@ class _tpl_curve_data:
     self.y = y
     self.xerror = xerror
     self.yerror = yerror
+    self.mark = _tpl_attribute_variable(token="mark", value=mark)
 
     if sortdata:
       self.x, self.y, self.xerror, self.yerror = self.__class__.__sort(self.x, self.y, self.xerror, self.yerror)
 
-    self.label = _tpl_attribute_function(
+    self.label = _tpl_curve_label(
         token="addlegendentry", value=label,
         suppress_semicolon=True
     )
     self.tablename = "table%d" % self.__class__.__counter
     self.__class__.__counter += 1
     self.color = _tpl_attribute_variable(token="color", value=color)
+    self.opacity = _tpl_attribute_variable(token="opacity", value=opacity)
