@@ -13,5 +13,5 @@ class _tpl_curve_generator_correlated_data(_tpl_curve_generator):
     color = "=%s" % self.curve.color.get_value() if self.curve.color.get_value() is not None else ""
     return "draw%s," % color
 
-  def _get_marks(self):
+  def _get_marks_active(self):
     return "% marks,"
