@@ -49,7 +49,7 @@ class _tpl_curve_generator:
   def _get_type(self):
     return "% type (ybar, ybar interval)"
 
-  def _get_marks(self):
+  def _get_marks_active(self):
     return "only marks,"
 
   def _get_legend_type(self):
@@ -60,11 +60,11 @@ class _tpl_curve_generator:
     yerrorstr = "y dir=both,\n  y explicit," if self.curve.yerror is not None else "% y error options"
 
     if self.curve.xerror is not None or self.curve.yerror is not None:
-      errormarkstr = f"""  error mark options={{
+      errormarkstr = f"""error mark options={{
     rotate=90,
     mark size=4pt,
     {self._get_errdraw()}
-  }}"""
+  }},"""
     else:
       errormarkstr = "  % error mark options"
 
@@ -75,11 +75,15 @@ class _tpl_curve_generator:
   {self.curve.color}
   {self._get_fill()}
   {self._get_draw()}
-  {self._get_marks()}
+  {self._get_marks_active()}
+  {self.curve.mark if self._get_marks_active() != "no marks" else "% mark"}
   {"error bars/.cd," if self.curve.xerror is not None or self.curve.yerror is not None else "% error options"}
   {self._get_errorstr()}
+  {"/tikz/.cd," if self.curve.xerror is not None or self.curve.yerror is not None else "% end error options"}
   {self._get_type()}
   {self._get_legend_type()}
+  {self.curve.opacity}
+  {"forget plot," if self.curve.label.get_value() is None else "% forget plot"}
 ] table [
   x=x,
   {"x error=dx," if self.curve.xerror is not None else "% x error"}
