@@ -23,7 +23,7 @@ class _tpl_curve_generator_ybar(_tpl_curve_generator):
   def _get_type(self):
     return "ybar,"
 
-  def _get_marks(self):
+  def _get_marks_active(self):
     return "no marks,"
 
   def _get_legend_type(self):
